powered by
Standard Normal Gammp prior calculates the posterior distribution for the fine mapping study. The number of individuals must be greater than the number of SNPs.
s_ng(y, data, medstar = 1, numb = 100, burnin = 1, every = 1)
A list including:
A vector of the posterior distribution of the intercept.
A matrix of the posterior distribution of the effect sizes.
A vector of the posterior distribution of \(\sigma^2\).
A matrix of the posterior distribution of \(\psi\).
A vector of the posterior distribution of \(\lambda\).
A vector of the posterior distribution of \(\gamma^2\).
A vector of the pheontype.
An \(N \times p\) finemap data, where \(N\) and \(p\) denote the samples and number of SNPs respectively.
The value of M.
Number of samples for each SNP.
The amount of burn-in for the MCMC sample.
The amount of thining for the MCMC sample.
Abulaziz Alenazi.
R implementation and documentation: Abulaziz Alenazi a.alenazi@nbu.edu.sa.
set.seed(1) data <- matrix( rnorm(500 * 30), ncol = 30) s_ng(y = rnorm(500), data = data)
Run the code above in your browser using DataLab