powered by
Standard Normal Gammp prior calculates the posterior distribution for the fine mapping cases-controls study. The number of case-controls must be greater than the number of SNPs.
asym_s_ng(y, data, medstar = 1, numb = 100, burnin = 1, every = 1)
A list including:
A vector of the posterior distribution of the intercept.
A matrix of the posterior distribution of the effect sizes.
A matrix of the posterior distribution of \(\psi\).
A vector of the posterior distribution of \(\lambda\).
A vector of the posterior distribution of \(\gamma^2\).
A vector of the pheontype, where takes 0s and 1s.
An \(N \times p\) finemap data, where \(N\) and \(p\) denote the samples and number of SNPs respectively.
The value of M.
Number of samples for each SNP.
The amount of burn-in for the MCMC sample.
The amount of thining for the MCMC sample.
Abulaziz Alenazi.
R implementation and documentation: Abulaziz Alenazi a.alenazi@nbu.edu.sa.
set.seed( 1 ) data <- matrix(sample( c( 0, 1, 2 ), 500 * 30, replace = TRUE, prob = c( 0.35, 0.35, 0.3)), ncol = 30) asym_s_ng(y = rbinom(500, 1, 0.5), data = data)
Run the code above in your browser using DataLab